==> jc-1.4.0.tar.gz: gnu/java/security/provider/DSAKeyFactory.h <==
// public class gnu.java.security.provider.DSAKeyFactory

// class file dependencies
// @dep_class 54be5494c58fd4a8 gnu_java_security_provider_DSAKeyFactory
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5208a7db73e048db java_security_KeyFactorySpi

// header file dependencies
// @dep_header java_security_KeyFactorySpi

#include "java/security/KeyFactorySpi.h"

#ifndef _JC_gnu_java_security_provider_DSAKeyFactory_H_
#define _JC_gnu_java_security_provider_DSAKeyFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Key$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_spec_KeySpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$sub_refs	_jc_gnu_java_security_provider_DSAKeyFactory$sub_refs;
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$sub_nonrefs	_jc_gnu_java_security_provider_DSAKeyFactory$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$refs	_jc_gnu_java_security_provider_DSAKeyFactory$refs;
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$nonrefs	_jc_gnu_java_security_provider_DSAKeyFactory$nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$object	_jc_gnu_java_security_provider_DSAKeyFactory$object;

typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$fields_struct	_jc_gnu_java_security_provider_DSAKeyFactory$fields_struct;
typedef const struct _jc_gnu_java_security_provider_DSAKeyFactory$vmethods	_jc_gnu_java_security_provider_DSAKeyFactory$vmethods;
typedef const struct _jc_gnu_java_security_provider_DSAKeyFactory$vtable	_jc_gnu_java_security_provider_DSAKeyFactory$vtable;
typedef const struct _jc_gnu_java_security_provider_DSAKeyFactory$vtype	_jc_gnu_java_security_provider_DSAKeyFactory$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_DSAKeyFactory$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAPrivateKeySpec;
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAPublicKeySpec;
};
extern _jc_gnu_java_security_provider_DSAKeyFactory$fields_struct _jc_gnu_java_security_provider_DSAKeyFactory$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_DSAKeyFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_provider_DSAKeyFactory$method$engineGeneratePrivate$5f899f5d07075f18(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_java_security_provider_DSAKeyFactory$method$engineGeneratePublic$7ad176effa9fa186(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *);
extern struct _jc_object *_jc_gnu_java_security_provider_DSAKeyFactory$method$engineGetKeySpec$8e11b093f262567f(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_gnu_java_security_provider_DSAKeyFactory$method$engineTranslateKey$486445c69e67c534(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DSAKeyFactory$method_info$engineGeneratePrivate$5f899f5d07075f18;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyFactory$method_info$engineGeneratePublic$7ad176effa9fa186;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyFactory$method_info$engineGetKeySpec$8e11b093f262567f;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyFactory$method_info$engineTranslateKey$486445c69e67c534;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_DSAKeyFactory$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_provider_DSAKeyFactory$vmethods {
	struct _jc_object	*(*engineGeneratePrivate$5f899f5d07075f18)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *);
	struct _jc_object	*(*engineGeneratePublic$7ad176effa9fa186)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *);
	struct _jc_object	*(*engineGetKeySpec$8e11b093f262567f)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
	struct _jc_object	*(*engineTranslateKey$486445c69e67c534)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_security_provider_DSAKeyFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyFactorySpi$vmethods	java_security_KeyFactorySpi;
	_jc_gnu_java_security_provider_DSAKeyFactory$vmethods	gnu_java_security_provider_DSAKeyFactory;
};

// Vtype
struct _jc_gnu_java_security_provider_DSAKeyFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DSAKeyFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAKeyFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAKeyFactory$refs {
    _jc_gnu_java_security_provider_DSAKeyFactory$sub_refs	gnu_java_security_provider_DSAKeyFactory;
    _jc_java_security_KeyFactorySpi$sub_refs	java_security_KeyFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAKeyFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAKeyFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyFactorySpi$sub_nonrefs	java_security_KeyFactorySpi;
    _jc_gnu_java_security_provider_DSAKeyFactory$sub_nonrefs	gnu_java_security_provider_DSAKeyFactory;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DSAKeyFactory$object {
	_jc_gnu_java_security_provider_DSAKeyFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DSAKeyFactory$vtype	*vtype;
	_jc_gnu_java_security_provider_DSAKeyFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DSAKeyFactory$vtype _jc_gnu_java_security_provider_DSAKeyFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DSAKeyFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DSAKeyFactory$class_object;

#endif	/* _JC_gnu_java_security_provider_DSAKeyFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/DSAKeyFactory.h <==
// public class gnu.java.security.provider.DSAKeyFactory

// class file dependencies
// @dep_class 54be5494c58fd4a8 gnu_java_security_provider_DSAKeyFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5208a7db73e048db java_security_KeyFactorySpi

// header file dependencies
// @dep_header java_security_KeyFactorySpi

#include "java/security/KeyFactorySpi.h"

#ifndef _JC_gnu_java_security_provider_DSAKeyFactory_H_
#define _JC_gnu_java_security_provider_DSAKeyFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Key$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_spec_KeySpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$sub_refs	_jc_gnu_java_security_provider_DSAKeyFactory$sub_refs;
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$sub_nonrefs	_jc_gnu_java_security_provider_DSAKeyFactory$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$refs	_jc_gnu_java_security_provider_DSAKeyFactory$refs;
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$nonrefs	_jc_gnu_java_security_provider_DSAKeyFactory$nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$object	_jc_gnu_java_security_provider_DSAKeyFactory$object;

typedef struct _jc_gnu_java_security_provider_DSAKeyFactory$fields_struct	_jc_gnu_java_security_provider_DSAKeyFactory$fields_struct;
typedef const struct _jc_gnu_java_security_provider_DSAKeyFactory$vmethods	_jc_gnu_java_security_provider_DSAKeyFactory$vmethods;
typedef const struct _jc_gnu_java_security_provider_DSAKeyFactory$vtable	_jc_gnu_java_security_provider_DSAKeyFactory$vtable;
typedef const struct _jc_gnu_java_security_provider_DSAKeyFactory$vtype	_jc_gnu_java_security_provider_DSAKeyFactory$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_DSAKeyFactory$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAPrivateKeySpec;
	struct _jc_java_lang_Class$object	*class__24java__24security__24spec__24DSAPublicKeySpec;
};
extern _jc_gnu_java_security_provider_DSAKeyFactory$fields_struct _jc_gnu_java_security_provider_DSAKeyFactory$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_DSAKeyFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_provider_DSAKeyFactory$method$engineGeneratePrivate$5f899f5d07075f18(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_DSAKeyFactory$method$engineGeneratePublic$7ad176effa9fa186(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_DSAKeyFactory$method$engineGetKeySpec$8e11b093f262567f(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_DSAKeyFactory$method$engineTranslateKey$486445c69e67c534(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DSAKeyFactory$method_info$engineGeneratePrivate$5f899f5d07075f18;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyFactory$method_info$engineGeneratePublic$7ad176effa9fa186;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyFactory$method_info$engineGetKeySpec$8e11b093f262567f;
extern _jc_method _jc_gnu_java_security_provider_DSAKeyFactory$method_info$engineTranslateKey$486445c69e67c534;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_provider_DSAKeyFactory$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_provider_DSAKeyFactory$vmethods {
	struct _jc_object	*(*engineGeneratePrivate$5f899f5d07075f18)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGeneratePublic$7ad176effa9fa186)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGetKeySpec$8e11b093f262567f)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineTranslateKey$486445c69e67c534)(_jc_env *, struct _jc_gnu_java_security_provider_DSAKeyFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_DSAKeyFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyFactorySpi$vmethods	java_security_KeyFactorySpi;
	_jc_gnu_java_security_provider_DSAKeyFactory$vmethods	gnu_java_security_provider_DSAKeyFactory;
};

// Vtype
struct _jc_gnu_java_security_provider_DSAKeyFactory$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DSAKeyFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAKeyFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAKeyFactory$refs {
    _jc_gnu_java_security_provider_DSAKeyFactory$sub_refs	gnu_java_security_provider_DSAKeyFactory;
    _jc_java_security_KeyFactorySpi$sub_refs	java_security_KeyFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAKeyFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAKeyFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyFactorySpi$sub_nonrefs	java_security_KeyFactorySpi;
    _jc_gnu_java_security_provider_DSAKeyFactory$sub_nonrefs	gnu_java_security_provider_DSAKeyFactory;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DSAKeyFactory$object {
	_jc_gnu_java_security_provider_DSAKeyFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DSAKeyFactory$vtype	*vtype;
	_jc_gnu_java_security_provider_DSAKeyFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DSAKeyFactory$vtype _jc_gnu_java_security_provider_DSAKeyFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DSAKeyFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DSAKeyFactory$class_object;

#endif	/* _JC_gnu_java_security_provider_DSAKeyFactory_H_ */
